@@ -67,7 +67,7 @@ public:
     inline pcolor(float red, float green, float blue) : QColor(
             (int) (255*(red * fraction + base)),
             (int) (255*(green * fraction + base)),
-            (int) (255*(blue * fraction + base)) ) { }
+            (int) (255*(blue * fraction + base))) { }
 };
 
 static void reset_rgb(float rgb[TIMELINE_HEIGHT][3])
@@ -396,12 +396,16 @@ void WirelessTimeline::wheelEvent(QWheelEvent *event)
 {
     // "Most mouse types work in steps of 15 degrees, in which case the delta
     // value is a multiple of 120; i.e., 120 units * 1/8 = 15 degrees"
-    double steps = event->delta() / 120.0;
+    double steps = event->angleDelta().y() / 120.0;
     if (steps != 0.0) {
         zoom_level += steps;
         if (zoom_level < 0) zoom_level = 0;
         if (zoom_level > TIMELINE_MAX_ZOOM) zoom_level = TIMELINE_MAX_ZOOM;
-        zoom((float)event->pos().x() / width());
+#if QT_VERSION >= QT_VERSION_CHECK(5, 15, 0)
+        zoom(event->position().x() / width());
+#else
+        zoom(event->posF().x() / width());
+#endif
     }
 }
 
@@ -498,7 +502,7 @@ WirelessTimeline::paintEvent(QPaintEvent *qpe)
 
     frame_data * topData = packet_list->getFDataForRow(top);
     frame_data * botData = packet_list->getFDataForRow(bottom);
-    if ( ! topData || ! botData )
+    if (! topData || ! botData)
         return;
 
     int x1 = top == -1 ? 0 : position(get_wlan_radio(topData->num)->start_tsf, ratio);
